emailuis/nmailui/src/nmeditorcontent.cpp
changeset 23 2dc6caa42ec3
parent 20 ecc8def7944a
child 30 759dc5235cdb
--- a/emailuis/nmailui/src/nmeditorcontent.cpp	Mon May 03 12:23:15 2010 +0300
+++ b/emailuis/nmailui/src/nmeditorcontent.cpp	Fri May 14 15:41:10 2010 +0300
@@ -51,9 +51,12 @@
     mEditorWidget->setDocument(textDocument); 
     textDocument->setParent(mEditorWidget); // ownership changes
 
-    mEditorWidget->init(this, mBackgroundScrollArea);
-    
-    // Remove the comment to enable style picker menu item.
+    mEditorWidget->init(mBackgroundScrollArea);
+    // we are interested in the editor widget's height changes
+    connect(mEditorWidget, SIGNAL(editorContentHeightChanged()), this,
+        SLOT(setEditorContentHeight()));
+
+    // Enable style picker menu item.
     mEditorWidget->setFormatDialog(new HbFormatDialog());
 
     // Create signal slot connections
@@ -112,7 +115,7 @@
     // Original message text to editor content fiel
     if (replyMsgEnvelope && mEditorWidget) {          
         QTextCursor cursor = mEditorWidget->textCursor();
-        cursor.setPosition(1);
+        cursor.setPosition(0);
         cursor.insertHtml(NmUtilities::createReplyHeader(*replyMsgEnvelope));
     }
 }